# coding: utf-8

"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ContainerImageAvailabilityRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'timeout': 'int',
        'images': 'list[str]'
    }

    attribute_map = {
        'timeout': 'timeout',
        'images': 'images'
    }

    def __init__(self, timeout=None, images=None):  # noqa: E501
        """ContainerImageAvailabilityRequest - a model defined in Swagger"""  # noqa: E501

        self._timeout = None
        self._images = None
        self.discriminator = None

        if timeout is not None:
            self.timeout = timeout
        self.images = images

    @property
    def timeout(self):
        """Gets the timeout of this ContainerImageAvailabilityRequest.  # noqa: E501

        Positive number represents a timeout in seconds for a pull operation.  # noqa: E501

        :return: The timeout of this ContainerImageAvailabilityRequest.  # noqa: E501
        :rtype: int
        """
        return self._timeout

    @timeout.setter
    def timeout(self, timeout):
        """Sets the timeout of this ContainerImageAvailabilityRequest.

        Positive number represents a timeout in seconds for a pull operation.  # noqa: E501

        :param timeout: The timeout of this ContainerImageAvailabilityRequest.  # noqa: E501
        :type: int
        """

        self._timeout = timeout

    @property
    def images(self):
        """Gets the images of this ContainerImageAvailabilityRequest.  # noqa: E501

        List of image names to be checked.  # noqa: E501

        :return: The images of this ContainerImageAvailabilityRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._images

    @images.setter
    def images(self, images):
        """Sets the images of this ContainerImageAvailabilityRequest.

        List of image names to be checked.  # noqa: E501

        :param images: The images of this ContainerImageAvailabilityRequest.  # noqa: E501
        :type: list[str]
        """
        if images is None:
            raise ValueError("Invalid value for `images`, must not be `None`")  # noqa: E501

        self._images = images

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ContainerImageAvailabilityRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContainerImageAvailabilityRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
